# Archived Design Documents

Documents may appear in the `rfcs/archived` directory for one of 
two reasons:

1. The document describes a feature or extension that has been deprecated and 
then removed.
2. The document describes a proposed feature or extension that have
not (ultimately) become a fully supported feature. 

Design documents that appear in the `rfcs/archived` folder should describe a 
reason for archiving.  Documents may 
remain in this folder indefinitely to serve as a source of information about
previous proposals and features.
